sciplot package
===============

Subpackages
-----------

.. toctree::

    sciplot.data
    sciplot.ui
    sciplot.utils

Submodules
----------

sciplot.sciplotUI module
------------------------

.. automodule:: sciplot.sciplotUI
    :members:
    :undoc-members:
    :show-inheritance:

sciplot.sciplotUI\_addon module
-------------------------------

.. automodule:: sciplot.sciplotUI_addon
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: sciplot
    :members:
    :undoc-members:
    :show-inheritance:
